@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use Moo;
 use strictures 2;
@@ -97,10 +97,22 @@ sub _build_groups {
 }
 
 has _pool_group => (
-    is       => 'ro',
-    init_arg => undef,
+    is      => 'ro',
+    builder => 1,
+    lazy    => 1,
 );
 
+sub _build__pool_group {
+    my ($self) = @_;
+
+    my %pool_group;
+    for my $i (0 .. @{ $self->pool } - 1) {
+        $pool_group{ $self->pool->[$i] } = $self->groups->[$i];
+    }
+
+    return \%pool_group;
+}
+
 
 has verbose => (
     is      => 'ro',
@@ -108,17 +120,6 @@ has verbose => (
 );
 
 
-sub BUILD {
-    my ($self, $args) = @_;
-
-    my %pool_group;
-    for my $i (0 .. @{ $self->pool } - 1) {
-        $pool_group{ $self->pool->[$i] } = $self->groups->[$i];
-    }
-    $self->{_pool_group} = \%pool_group;
-}
-
-
 sub motif {
     my ($self) = @_;
 
@@ -203,7 +204,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -339,8 +340,6 @@ Default: C<0>
 
 Create a new C<Music::Duration::Partition> object.
 
-=for Pod::Coverage BUILD
-
 =head2 motif
 
   $motif = $mdp->motif;
